#!/usr/bin/env python

#-----------------------------------------------------------------------
# searchresults.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import os
import http.cookies
import html # html.escape() is used to thwart XSS attacks
import parseargs
import common
import database

def main():
    args_str = os.environ.get('QUERY_STRING', '')
    args = parseargs.parse(args_str)
    author = args.get('author', '')
    author = author.strip()

    if author == '':
        author = '(None)'
        books = []
    else:
        books = database.get_books(author) # Exception handling omitted

    cookie = http.cookies.SimpleCookie()
    cookie['prev_author'] = author

    # Print HTTP header.
    print('Content-type: text/html; charset=utf-8')
    print(cookie.output())
    print()

    # Print content.
    print('<!DOCTYPE html>')
    print('<html>')
    print('<head>')
    print('<title>Penny.com</title>')
    print('</head>')
    print('<body>')
    common.print_header()
    print('<h1>Author Search Results</h1>')
    print('<h2>Books by ' + html.escape(author) + ':</h2>')
    if len(books) == 0:
        print('(None)<br>')
    else:
        pattern = '%s: <strong>%s</strong>: %s<br>'
        for book in books:
            print(pattern %
                (book['isbn'], book['author'], book['title']))
    print('<br>')
    print('<br>')
    print('Click here to do another ')
    print('<a href="/cgi-bin/searchform.py">author search</a>.')
    print('<br>')
    print('<br>')
    print('<br>')
    print('<br>')
    common.print_footer()
    print('</body>')
    print('</html>')
#-----------------------------------------------------------------------
if __name__ == '__main__':
    main()
